import { Component, Directive, TemplateRef, Input, EventEmitter, ContentChildren, Output, ViewChild, NgModule } from '@angular/core';
import { map } from 'rxjs/operators';
import { Router, ActivatedRoute, RouterModule } from '@angular/router';
import { Location, CommonModule } from '@angular/common';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import { MatSort, MatSortModule } from '@angular/material/sort';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { MatTableModule } from '@angular/material/table';
import { MatCardModule } from '@angular/material/card';
import { MatFormFieldModule } from '@angular/material/form-field';

class LayoutComponent {
    constructor() { }
    ngOnInit() {
    }
}
LayoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-layout',
                template: `
    <p>
      layout works!
    </p>
  `
            },] }
];
/** @nocollapse */
LayoutComponent.ctorParameters = () => [];

class TableRowColumnDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
TableRowColumnDirective.decorators = [
    { type: Directive, args: [{ selector: 'ng-template[rowColumn]' },] }
];
/** @nocollapse */
TableRowColumnDirective.ctorParameters = () => [
    { type: TemplateRef }
];
TableRowColumnDirective.propDecorators = {
    rowColumn: [{ type: Input }]
};
class TableContentComponent {
    constructor(router, activatedRoute, location) {
        this.router = router;
        this.activatedRoute = activatedRoute;
        this.location = location;
        this.hasToolbar = true;
        this.hasSearch = true;
        this.hasAddButton = true;
        this.hasBackButton = true;
        this.hasPaginator = true;
        this.tableRowClick = new EventEmitter();
    }
    set tableLayoutInput(tl) {
        this._tableLayoutInput = tl;
    }
    ;
    get tableLayoutInput() {
        return this._tableLayoutInput;
    }
    set matSort(ms) {
        this.sort = ms;
    }
    set matPaginator(ms) {
        this.paginator = ms;
    }
    ngOnInit() {
        this.dataSource = this.tableLayoutInput.dataSource;
        this.dataSource.setPaginator(this.paginator);
        this.dataSource.setSort(this.sort);
        this.tableLayoutInput.columnDef.pipe(map(res => res.map(res => res.columnId))).subscribe(res => {
            this.displayedColumns = res;
        });
        this.tableLayoutInput.columnDef.pipe(map(res => res.map(res => res.columnName))).subscribe(res => {
            this.columnNames = res;
        });
        if (this.tableLayoutInput.addRoute) {
            this.addRoute = this.tableLayoutInput.addRoute;
        }
        if (this.tableLayoutInput.backRoute) {
            this.backRoute = this.tableLayoutInput.backRoute;
        }
    }
    ngAfterContentInit() {
        let columnMap = new Map();
        let refArray = this.rowColumnDirectives.toArray();
        refArray.forEach(val => {
            columnMap.set(val.rowColumn, val);
        });
        this.rowColumnTemplates = columnMap;
    }
    getPageSizeOptions() {
        return [5, 10, 20, 50, 100, 250];
    }
    getDefaultPageSize() {
        const tableFilter = this.dataSource.filterSubject.value;
        if (tableFilter && tableFilter.pager) {
            return tableFilter.pager.pageSize;
        }
        return 250;
    }
    add() {
        if (this.addRoute) {
            if (this.addRoute.queryParams) {
                this.router.navigate([this.addRoute.path], { queryParams: this.addRoute.queryParams });
            }
            else {
                this.router.navigate([this.addRoute.path]);
            }
        }
        else {
            this.router.navigate(['0'], { relativeTo: this.activatedRoute });
        }
    }
    back() {
        if (this.backRoute) {
            if (this.backRoute.queryParams) {
                this.router.navigate([this.backRoute.path], { queryParams: this.backRoute.queryParams });
            }
            else {
                this.router.navigate([this.backRoute.path]);
            }
        }
        else {
            this.location.back();
        }
    }
    onRowClick(row) {
        this.tableRowClick.emit(row);
    }
    reload(filter) {
        filter = Object.assign(Object.assign({}, this.dataSource.filterSubject.value), filter);
        this.dataSource.filterSubject.next(filter);
        return false;
    }
    navigateBack() {
        this.location.back();
    }
}
TableContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-table-content',
                template: "<mat-toolbar *ngIf=\"tableLayoutInput.title\" color=\"accent\" style=\"height:20px; opacity: 0.5\"><span\n  style=\"font-size: 0.7em\">{{tableLayoutInput?.title}}</span></mat-toolbar>\n<!-- =================================  Table search + dynamic filter comp + buttons =============================== -->\n<mat-toolbar style=\"height:90px\" class=\"table-layout-toolbar\" *ngIf=\"hasToolbar\">\n\n  <button mat-mini-fab name=\"cmd\" type=\"button\" (click)='back()' class=\"margin-right--small\" *ngIf=\"hasBackButton\">\n    <mat-icon>arrow_back</mat-icon>\n  </button>\n\n  <ng-container>   <!-- <ng-container *permissionEdit=\"tableLayoutInput.expectedRoles\">-->\n    <button *ngIf=\"!tableLayoutInput.disableAddButton && hasAddButton\" mat-mini-fab name=\"cmd\" type=\"button\"\n            value=\"create\" (click)=\"add()\" class=\"margin-right--small\">\n      <mat-icon>add</mat-icon>\n    </button>\n  </ng-container>\n\n  <!-- TODO fix this -->\n<!--  <button *ngIf=\"tableLayoutInput.downloadable\" mat-mini-fab name=\"excel\" type=\"button\"\n          (click)=\"dataSource.excelExport()\" class=\"margin-right&#45;&#45;small\">\n    <mat-icon>cloud_download</mat-icon>\n  </button>-->\n\n<!--  <table-search [searchFields]=\"tableLayoutInput.advanceSearchCriteria\"\n                [hasAdvanceSearch]=\"tableLayoutInput.advanceSearch\" *ngIf=\"tableLayoutInput.searchable && hasSearch\"\n                (changed)=\"reload($event)\"\n                class=\"margin-right&#45;&#45;small\"></table-search>-->\n\n  <div class=\"spacer\"></div>\n\n\n</mat-toolbar>\n\n<!-- =================================   Further table controls (e.g. tabs)========================================= -->\n\n<ng-content select=\"[controls]\"></ng-content>\n\n<!-- =================================   Paginator ================================================================= -->\n<div>\n  <mat-paginator #paginator [pageSizeOptions]=\"getPageSizeOptions()\">\n  </mat-paginator>\n</div>\n\n<!-- =================================== Mat Table ================================================================= -->\n<table #matTable mat-table [dataSource]=\"dataSource\" matSort\n       matSortActive=\"{{tableLayoutInput.matSortActive}}\" matSortDisableClear\n       matSortDirection=\"{{tableLayoutInput.matSortDirection ? tableLayoutInput.matSortDirection : 'desc'}}\">\n\n  <ng-container *ngFor=\"let column of displayedColumns;let i = index\" [matColumnDef]=\"column\">\n    <th mat-sort-header mat-header-cell *matHeaderCellDef>\n      {{columnNames[i]}}\n    </th>\n    <td mat-cell *matCellDef=\"let row\">\n      <ng-container [ngTemplateOutlet]=\"rowColumnTemplates.get(column)?.templateRef\"\n                    [ngTemplateOutletContext]=\"{$implicit: row}\"></ng-container>\n    </td>\n  </ng-container>\n\n  <tr mat-header-row *matHeaderRowDef=\"displayedColumns\"></tr>\n  <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onRowClick(row)\" class=\"row-click\"></tr>\n</table>\n\n<!-- ===================================== Loading indicator ======================================================= -->\n<mat-card fxLayout=\"row\" *ngIf=\"dataSource.status == 'loading'\" fxLayoutAlign=\"center\">\n  <!-- TODO extract loading indicator component to library <app-loading-indicator></app-loading-indicator>-->\n</mat-card>\n\n<!-- ===================================== Table empty ============================================================= -->\n<mat-card *ngIf=\"dataSource?.dataSubject?.value?.length === 0\" fxLayoutAlign=\"center\">\n  <span><!-- TODO should be configured as input prop -->Die Tabelle hat noch keine Eintr\u00E4ge!</span>\n</mat-card>\n\n<!-- ===================================== Table error ============================================================= -->\n<mat-card *ngIf=\"dataSource?.status === 'error'\" fxLayoutAlign=\"center\">\n  <mat-error><!-- TODO should be configured as input prop --> Es ist etwas falsch gelaufen</mat-error>\n</mat-card>\n"
            },] }
];
/** @nocollapse */
TableContentComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: Location }
];
TableContentComponent.propDecorators = {
    tableLayoutInput: [{ type: Input }],
    rowColumnDirectives: [{ type: ContentChildren, args: [TableRowColumnDirective,] }],
    hasToolbar: [{ type: Input }],
    hasSearch: [{ type: Input }],
    hasAddButton: [{ type: Input }],
    hasBackButton: [{ type: Input }],
    hasPaginator: [{ type: Input }],
    tableRowClick: [{ type: Output }],
    matSort: [{ type: ViewChild, args: [MatSort, { static: true },] }],
    matPaginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }]
};

class TableTitleComponent {
    constructor() { }
    ngOnInit() {
    }
}
TableTitleComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-table-title',
                template: "<p>\n  table-title works!\n</p>\n"
            },] }
];
/** @nocollapse */
TableTitleComponent.ctorParameters = () => [];

class TableHeaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
TableHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-table-header',
                template: "<mat-toolbar fxLayoutGap=\"10px\">\n  <ng-content></ng-content>\n  <div class=\"spacer\"></div>\n</mat-toolbar>\n"
            },] }
];
/** @nocollapse */
TableHeaderComponent.ctorParameters = () => [];

class TableLayoutComponent {
    constructor() {
        this.status = 'loading';
    }
    ngOnInit() {
    }
}
TableLayoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-table-layout',
                template: "<div class=\"table-layout mat-elevation-z12\">\n  <ng-content select=\"[content]\"></ng-content>\n</div>\n"
            },] }
];
/** @nocollapse */
TableLayoutComponent.ctorParameters = () => [];
TableLayoutComponent.propDecorators = {
    status: [{ type: Input }]
};

class TableContentResponsiveComponent {
    constructor(router, activatedRoute, location) {
        this.router = router;
        this.activatedRoute = activatedRoute;
        this.location = location;
        this.hasToolbar = true;
        this.hasSearch = true;
        this.hasAddButton = true;
        this.hasBackButton = true;
        this.hasPaginator = true;
        this.tableRowClick = new EventEmitter();
    }
    set tableLayoutInput(tl) {
        this._tableLayoutInput = tl;
    }
    get tableLayoutInput() {
        return this._tableLayoutInput;
    }
    set matSort(ms) {
        this.sort = ms;
    }
    set matPaginator(ms) {
        this.paginator = ms;
    }
    ngOnInit() {
        this.tableLayoutInput.dataSource.setPaginator(this.paginator);
        this.tableLayoutInput.dataSource.setSort(this.sort);
        this.tableLayoutInput.columnDef.pipe(map(res => res.map(res => res.columnId))).subscribe(res => {
            this.displayedColumns = res;
        });
        this.tableLayoutInput.columnDef.pipe(map(res => res.map(res => res.columnName))).subscribe(res => {
            this.columnNames = res;
        });
        if (this.tableLayoutInput.addRoute) {
            this.addRoute = this.tableLayoutInput.addRoute;
        }
    }
    ngAfterContentInit() {
        const columnMap = new Map();
        const refArray = this.rowColumnDirectives.toArray();
        refArray.forEach(val => {
            columnMap.set(val.rowColumn, val);
        });
        this.rowColumnTemplates = columnMap;
    }
    getPageSizeOptions() {
        return [5, 10, 20, 50, 100, 250];
    }
    getDefaultPageSize() {
        return 250;
    }
    add() {
        if (this.addRoute) {
            if (this.addRoute.queryParams) {
                this.router.navigate([this.addRoute.path], { queryParams: this.addRoute.queryParams });
            }
            else {
                this.router.navigate([this.addRoute.path]);
            }
        }
        else {
            this.router.navigate(['0'], { relativeTo: this.activatedRoute });
        }
    }
    onRowClick(row) {
        this.tableRowClick.emit(row);
    }
    reload(filter) {
        this.tableLayoutInput.dataSource.filterSubject.next(filter);
        return false;
    }
    navigateBack() {
        this.location.back();
    }
}
TableContentResponsiveComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-table-content-responsive',
                template: "<!-- =================================  Table search + dynamic filter comp + buttons =============================== -->\n<mat-toolbar style=\"height:90px\" class=\"table-layout-toolbar\" *ngIf=\"hasToolbar\">\n\n  <button mat-mini-fab name=\"cmd\" type=\"button\" [routerLink]=\"'..'\" class=\"margin-right--small\" *ngIf=\"hasBackButton\">\n    <mat-icon>arrow_back</mat-icon>\n  </button>\n\n  <ng-container><!-- <ng-container *permissionEdit=\"tableLayoutInput.expectedRoles\">-->\n    <button *ngIf=\"!tableLayoutInput.disableAddButton && hasAddButton\" mat-mini-fab name=\"cmd\" type=\"button\"\n            value=\"create\" (click)=\"add()\" class=\"margin-right--small\">\n      <mat-icon>add</mat-icon>\n    </button>\n  </ng-container>\n\n  <!-- TODO fix the excel export; probably those controls should be injectable via template/ngcontent -->\n<!--  <button *ngIf=\"tableLayoutInput.downloadable\" mat-mini-fab name=\"excel\" type=\"button\"\n          (click)=\"tableLayoutInput.dataSource.excelExport()\" class=\"margin-right&#45;&#45;small\">\n    <mat-icon>cloud_download</mat-icon>\n  </button>-->\n\n<!--  <table-search [searchFields]=\"tableLayoutInput.advanceSearchCriteria\"\n                [hasAdvanceSearch]=\"tableLayoutInput.advanceSearch\" *ngIf=\"tableLayoutInput.searchable && hasSearch\"\n                (changed)=\"reload($event)\"\n                class=\"margin-right&#45;&#45;small\"></table-search>-->\n\n  <div class=\"spacer\"></div>\n\n\n</mat-toolbar>\n\n<!-- =================================   Further table controls (e.g. tabs)========================================= -->\n\n<ng-content select=\"[controls]\"></ng-content>\n\n<!-- =================================   Paginator ================================================================= -->\n<div>\n  <mat-paginator #paginator [pageIndex]=\"0\" [pageSize]=\"getDefaultPageSize()\" [pageSizeOptions]=\"getPageSizeOptions()\">\n  </mat-paginator>\n</div>\n\n<!-- =================================== Mat Table ================================================================= -->\n<div class=\"base-table-responsive\">\n  <mat-table multiTemplateDataRows [dataSource]=\"tableLayoutInput.dataSource\" matSort\n             matSortActive=\"{{tableLayoutInput.matSortActive}}\" matSortDisableClear\n             matSortDirection=\"{{tableLayoutInput.matSortDirection ? tableLayoutInput.matSortDirection : 'desc'}}\"\n             class=\"expandable\">\n\n    <ng-container *ngFor=\"let column of displayedColumns;let i = index\" [matColumnDef]=\"column\">\n\n      <mat-header-cell *matHeaderCellDef mat-sort-header>\n        {{columnNames[i]}}\n      </mat-header-cell>\n      <mat-cell *matCellDef=\"let row\">\n        <span class=\"resp-row-label\" style=\"float:left; padding:0;\">{{columnNames[i]}}</span>\n        <ng-container [ngTemplateOutlet]=\"rowColumnTemplates.get(column)?.templateRef\"\n                      [ngTemplateOutletContext]=\"{$implicit: row}\"></ng-container>\n      </mat-cell>\n\n    </ng-container>\n\n\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onRowClick(row)\">\n    </mat-row>\n\n  </mat-table>\n</div>\n\n\n<!-- ===================================== Loading indicator ======================================================= -->\n<mat-card fxLayout=\"row\" *ngIf=\"tableLayoutInput.dataSource.status == 'loading'\" fxLayoutAlign=\"center\">\n<!-- TODO put loading indicator here  <app-loading-indicator></app-loading-indicator>-->\n</mat-card>\n\n\n\n",
                animations: [
                    trigger('detailExpand', [
                        state('collapsed', style({ height: '0px', minHeight: '0', display: 'none' })),
                        state('expanded', style({ height: '*' })),
                        transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
                    ]),
                ]
            },] }
];
/** @nocollapse */
TableContentResponsiveComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: Location }
];
TableContentResponsiveComponent.propDecorators = {
    tableLayoutInput: [{ type: Input }],
    rowColumnDirectives: [{ type: ContentChildren, args: [TableRowColumnDirective,] }],
    hasToolbar: [{ type: Input }],
    hasSearch: [{ type: Input }],
    hasAddButton: [{ type: Input }],
    hasBackButton: [{ type: Input }],
    hasPaginator: [{ type: Input }],
    tableRowClick: [{ type: Output }],
    matSort: [{ type: ViewChild, args: [MatSort, { static: true },] }],
    matPaginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }]
};

class TableLayoutModule {
}
TableLayoutModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    TableRowColumnDirective,
                    TableContentComponent,
                    TableTitleComponent,
                    TableHeaderComponent,
                    TableLayoutComponent,
                    TableContentResponsiveComponent
                ],
                imports: [
                    MatToolbarModule,
                    MatIconModule,
                    MatButtonModule,
                    CommonModule,
                    MatPaginatorModule,
                    MatTableModule,
                    MatSortModule,
                    MatCardModule,
                    MatFormFieldModule,
                    RouterModule,
                ],
                exports: [
                    TableRowColumnDirective,
                    TableContentComponent,
                    TableTitleComponent,
                    TableHeaderComponent,
                    TableLayoutComponent,
                    TableContentResponsiveComponent
                ]
            },] }
];

class LayoutModule {
}
LayoutModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LayoutComponent],
                imports: [
                    TableLayoutModule
                ],
                exports: [
                    TableLayoutModule
                ]
            },] }
];

/*
 * Public API Surface of layout
 */

/**
 * Generated bundle index. Do not edit.
 */

export { LayoutModule, TableContentComponent, TableContentResponsiveComponent, TableHeaderComponent, TableLayoutComponent, TableLayoutModule, TableRowColumnDirective, TableTitleComponent, LayoutComponent as ɵa };
//# sourceMappingURL=yukawa-chain-base-angular-layout.js.map
